@@ -377,7 +377,7 @@ class MLP:
         :return: Lemmatized string.
         """
         document = self.process(raw_text, analyzers=["lemmas"], lang=lang)
-        return document["text"]["lemmas"]
+        return document["text_mlp"]["lemmas"]
 
 
     def parse_doc_texts(self, doc_path: str, document: dict) -> list:
